@@ -1,26 +1,7 @@
 from __future__ import absolute_import
+from __future__ import division
 # Copyright (c) 2010-2015 openpyxl
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-#
-# @license: http://www.opensource.org/licenses/mit-license.php
-# @author: see AUTHORS file
+
 
 from openpyxl.drawing import Drawing, Shape
 
@@ -102,7 +83,7 @@ class Chart(object):
 
         mb = Shape.FONT_HEIGHT + Shape.MARGIN_BOTTOM
         plot_height = self.drawing.height * self.height
-        return float(self.drawing.height - plot_height - mb) / self.drawing.height
+        return (self.drawing.height - plot_height - mb) / self.drawing.height
 
     @property
     def margin_left(self):
@@ -114,6 +95,10 @@ class Chart(object):
         self._margin_left = value
 
     def _get_min_margin_left(self):
+        try:
+            ychars = self.get_y_chars()
+        except TypeError:
+            ychars = 0
 
-        ml = (self.get_y_chars() * Shape.FONT_WIDTH) + Shape.MARGIN_LEFT
-        return float(ml) / self.drawing.width
+        ml = (ychars * Shape.FONT_WIDTH) + Shape.MARGIN_LEFT
+        return ml / self.drawing.width
