@@ -40,7 +40,13 @@ DARKYELLOW = COLOR_INDEX[19]
 aRGB_REGEX = re.compile("^([A-Fa-f0-9]{8}|[A-Fa-f0-9]{6})$")
 
 
-class RGB(Descriptor):
+class RGB(Typed):
+    """
+    Descriptor for aRGB values
+    If not supplied alpha is 00
+    """
+
+    expected_type = basestring
 
     def __set__(self, instance, value):
         m = aRGB_REGEX.match(value)
@@ -54,6 +60,8 @@ class RGB(Descriptor):
 class Color(HashableObject):
     """Named colors for use in styles."""
 
+    tagname = "color"
+
     rgb = RGB()
     indexed = Integer()
     auto = Bool()
@@ -68,7 +76,7 @@ class Color(HashableObject):
             indexed = index
         if indexed is not None:
             self.type = 'indexed'
-            self.indexed = int(indexed)
+            self.indexed = indexed
         elif theme is not None:
             self.type = 'theme'
             self.theme = theme
@@ -84,6 +92,10 @@ class Color(HashableObject):
     def value(self):
         return getattr(self, self.type)
 
+    @value.setter
+    def value(self, value):
+        setattr(self, self.type, value)
+
     def __iter__(self):
         attrs = [(self.type, self.value)]
         if self.tint != 0:
